## aircheck v0.1.1

### Fixes
- Use check result objects instead of exceptions ([#2](https://github.com/AleksanderWWW/aircheck/pull/2))

## aircheck v0.1.0

### Project initialization
- Prepare for the first release ([#1](https://github.com/AleksanderWWW/aircheck/pull/1))
